==> snaxdart_models-1.0.1.tar.gz: lib/src/v1/app_state.dart <==
import 'package:json_annotation/json_annotation.dart';
import 'package:equatable/equatable.dart';
import 'package:snaxdart_models/v1.dart';

part 'app_state.g.dart';

@JsonSerializable()
class AppState extends Equatable {
  @JsonKey(name: 'wallet')
  final Wallet wallet;

  @JsonKey(name: 'accounts')
  final Accounts accounts;

  @JsonKey(name: 'global')
  final Global global;

  @JsonKey(name: 'transactions')
  final WalletTransactions transactions;

  @JsonKey(name: 'sign_up')
  final SignUp signUp;

  @JsonKey(name: 'transfer', ignore: true)
  final Transfer transfer;

  AppState({
    this.wallet,
    this.accounts,
    this.global,
    this.transactions,
    transfer,
    signUp,
  })  : this.signUp = signUp ?? SignUp.initialState(),
        this.transfer = transfer ?? Transfer.initialState(),
        super();

  AppState.initialState()
      : wallet = Wallet.initialState(),
        accounts = Accounts.initialState(),
        global = Global.initialState(),
        signUp = SignUp.initialState(),
        transfer = Transfer.initialState(),
        transactions = WalletTransactions.initialState();

  AppState copyWith({
    Wallet wallet,
    Accounts accounts,
    Global global,
    SignUp signUp,
    WalletTransactions transactions,
    Transfer transfer,
  }) {
    return AppState(
      wallet: wallet ?? this.wallet,
      accounts: accounts ?? this.accounts,
      global: global ?? this.global,
      signUp: signUp ?? this.signUp,
      transfer: transfer ?? this.transfer,
      transactions: transactions ?? this.transactions,
    );
  }

  static AppState fromJson(dynamic json) {
    if (json == null) {
      return AppState.initialState();
    }

    return _$AppStateFromJson(json);
  }

  Map<String, dynamic> toJson() => _$AppStateToJson(this);

  @override
  String toString() => this.toJson().toString();
}

==> snaxdart_models-1.1.2.tar.gz: lib/src/v1/app_state.dart <==
import 'package:json_annotation/json_annotation.dart';
import 'package:equatable/equatable.dart';
import 'package:snaxdart_models/v1.dart';

part 'app_state.g.dart';

@JsonSerializable()
class AppState extends Equatable {
  @JsonKey(name: 'wallet')
  final Wallet wallet;

  @JsonKey(name: 'accounts')
  final Accounts accounts;

  @JsonKey(name: 'global')
  final Global global;

  @JsonKey(name: 'transactions')
  final WalletTransactions transactions;

  @JsonKey(name: 'sign_up')
  final SignUp signUp;

  @JsonKey(name: 'transfer')
  final Transfer transfer;

  AppState({
    this.wallet,
    this.accounts,
    this.global,
    this.transactions,
    transfer,
    signUp,
  })  : this.signUp = signUp ?? SignUp.initialState(),
        this.transfer = transfer ?? Transfer.initialState(),
        super();

  AppState.initialState()
      : wallet = Wallet.initialState(),
        accounts = Accounts.initialState(),
        global = Global.initialState(),
        signUp = SignUp.initialState(),
        transfer = Transfer.initialState(),
        transactions = WalletTransactions.initialState();

  AppState copyWith({
    Wallet wallet,
    Accounts accounts,
    Global global,
    SignUp signUp,
    WalletTransactions transactions,
    Transfer transfer,
  }) {
    return AppState(
      wallet: wallet ?? this.wallet,
      accounts: accounts ?? this.accounts,
      global: global ?? this.global,
      signUp: signUp ?? this.signUp,
      transfer: transfer ?? this.transfer,
      transactions: transactions ?? this.transactions,
    );
  }

  static AppState fromJson(dynamic json) {
    if (json == null) {
      return AppState.initialState();
    }

    return _$AppStateFromJson(json);
  }

  Map<String, dynamic> toJson() => _$AppStateToJson(this);

  @override
  String toString() => this.toJson().toString();
}
